import sys

from os import getenv

try:
    from dotenv import load_dotenv

    load_dotenv()
except ImportError:
    pass


MSG_PERMIT = (
    """
╔═════════════════════╗
│  𖣘 𝚂𝙴𝙻𝙰𝙼𝙰𝚃 𝙳𝙰𝚃𝙰𝙽𝙶 𝚃𝙾𝙳 𖣘ㅤ  ㅤ
╚═════════════════════╝
 ⍟ 𝙹𝙰𝙽𝙶𝙰𝙽 𝚂𝙿𝙰𝙼 𝙲𝙷𝙰𝚃 𝙼𝙰𝙹𝙸𝙺𝙰𝙽 𝙶𝚄𝙰 𝙺𝙴𝙽𝚃𝙾𝙳
 ⍟ 𝙶𝚄𝙰 𝙰𝙺𝙰𝙽 𝙾𝚃𝙾𝙼𝙰𝚃𝙸𝚂 𝙱𝙻𝙾𝙺𝙸𝚁 𝙺𝙰𝙻𝙾 𝙻𝚄 𝚂𝙿𝙰𝙼
 ⍟ 𝙹𝙰𝙳𝙸 𝚃𝚄𝙽𝙶𝙶𝚄 𝚂𝙰𝙼𝙿𝙰𝙸 𝙼𝙰𝙹𝙸𝙺𝙰𝙽 𝙶𝚄𝙰 𝙽𝙴𝚁𝙸𝙼𝙰 𝙿𝙴𝚂𝙰𝙽 𝙻𝚄
╔═════════════════════╗
│ㅤㅤ𖣘 𝙿𝙴𝚂𝙰𝙽 𝙾𝚃𝙾𝙼𝙰𝚃𝙸𝚂 𖣘ㅤㅤ
│ㅤㅤ   𖣘 𝙰𝚈𝙸𝙸𝙽 - 𝚄𝙱𝙾𝚃 𖣘ㅤㅤ
╚═════════════════════╝
"""
)



class Var(object):
    # mandatory
    API_ID = int(getenv("API_ID"))
    API_HASH = str(getenv("API_HASH"))
    # Extras
    ALIVE_PIC = getenv("ALIVE_PIC", "https://telegra.ph//file/78ec83169711f650f0188.jpg")
    ALIVE_TEXT = getenv("ALIVE_TEXT", "Hai, Saya AyiinUbot")
    ASS_STRING = getenv("ASS_STRING", "")
    TELEBOT = getenv("TELEBOT", "False")
    # Telethon Session
    STRING_1 = getenv("STRING_1", "")
    STRING_2 = getenv("STRING_2", "")
    STRING_3 = getenv("STRING_3", "")
    STRING_4 = getenv("STRING_4", "")
    STRING_5 = getenv("STRING_5", "")
    STRING_6 = getenv("STRING_6", "")
    STRING_7 = getenv("STRING_7", "")
    STRING_8 = getenv("STRING_8", "")
    STRING_9 = getenv("STRING_9", "")
    STRING_10 = getenv("STRING_10", "")
    
    # Pyrogram Session
    SESSION_1 = getenv("SESSION_1", "")
    SESSION_2 = getenv("SESSION_2", "")
    SESSION_3 = getenv("SESSION_3", "")
    SESSION_4 = getenv("SESSION_4", "")
    SESSION_5 = getenv("SESSION_5", "")
    SESSION_6 = getenv("SESSION_6", "")
    SESSION_7 = getenv("SESSION_7", "")
    SESSION_8 = getenv("SESSION_8", "")
    SESSION_9 = getenv("SESSION_9", "")
    SESSION_10 = getenv("SESSION_10", "")
    SESSION_11 = getenv("SESSION_11", "")
    SESSION_12 = getenv("SESSION_12", "")
    SESSION_13 = getenv("SESSION_13", "")
    SESSION_14 = getenv("SESSION_14", "")
    SESSION_15 = getenv("SESSION_15", "")
    SESSION_16 = getenv("SESSION_16", "")
    SESSION_17 = getenv("SESSION_17", "")
    SESSION_18 = getenv("SESSION_18", "")
    SESSION_19 = getenv("SESSION_19", "")
    SESSION_20 = getenv("SESSION_20", "")
    SESSION_21 = getenv("SESSION_21", "")
    SESSION_22 = getenv("SESSION_22", "")
    SESSION_23 = getenv("SESSION_23", "")
    SESSION_24 = getenv("SESSION_24", "")
    SESSION_25 = getenv("SESSION_25", "")
    SESSION_26 = getenv("SESSION_26", "")
    SESSION_27 = getenv("SESSION_27", "")
    SESSION_28 = getenv("SESSION_28", "")
    SESSION_29 = getenv("SESSION_29", "")
    SESSION_30 = getenv("SESSION_30", "")
    SESSION_31 = getenv("SESSION_31", "")
    SESSION_32 = getenv("SESSION_32", "")
    SESSION_33 = getenv("SESSION_33", "")
    SESSION_34 = getenv("SESSION_34", "")
    SESSION_35 = getenv("SESSION_35", "")
    SESSION_36 = getenv("SESSION_36", "")
    SESSION_37 = getenv("SESSION_37", "")
    SESSION_38 = getenv("SESSION_38", "")
    SESSION_39 = getenv("SESSION_39", "")
    SESSION_40 = getenv("SESSION_40", "")
    SESSION_41 = getenv("SESSION_41", "")
    SESSION_42 = getenv("SESSION_42", "")
    SESSION_43 = getenv("SESSION_43", "")
    SESSION_44 = getenv("SESSION_44", "")
    SESSION_45 = getenv("SESSION_45", "")
    SESSION_46 = getenv("SESSION_46", "")
    SESSION_47 = getenv("SESSION_47", "")
    SESSION_48 = getenv("SESSION_48", "")
    SESSION_49 = getenv("SESSION_49", "")
    SESSION_50 = getenv("SESSION_50", "")
    
    # For Handler
    HNDLR = getenv("HNDLR", [".", "!", "*", "^", "-", "?"])
    # Database
    REDIS_URI = (
        getenv("REDIS_URI", None) or getenv("REDIS_URL", None)
    )
    REDIS_PASSWORD = getenv("REDIS_PASSWORD", None)
    # extras
    BOT_TOKEN = getenv("BOT_TOKEN")
    LOG_CHAT = int(getenv("LOG_CHAT") or 0)
    HEROKU_APP_NAME = getenv("HEROKU_APP_NAME", None)
    HEROKU_API = getenv("HEROKU_API", None)
    TEMP_DOWNLOAD_DIRECTORY = getenv("TEMP_DOWNLOAD_DIRECTORY", "./downloads")
    NO_LOAD = [int(x) for x in getenv("NO_LOAD", "").split()]
    TZ = getenv("TZ", "Asia/Jakarta")
    PMPERMIT = getenv("PMPERMIT", "True")
    PERMIT_MSG = str(getenv("PERMIT_MSG", MSG_PERMIT))
    PERMIT_LIMIT = int(getenv("PERMIT_LIMIT", 6))
    # for railway
    REDISPASSWORD = getenv("REDISPASSWORD", None)
    REDISHOST = getenv("REDISHOST", None)
    REDISPORT = getenv("REDISPORT", None)
    REDISUSER = getenv("REDISUSER", None)
    # for sql
    DATABASE_URL = getenv("DATABASE_URL", None)
    # for MONGODB users
    MONGO_URI = getenv("MONGO_URI", None)
    # for Okteto Platform
    OKTETO = bool(getenv("OKTETO", False))




from fipper import idle

from pyAyiin import __version__

from . import *

from .config import Var
from .Clients.client import Bots
from .Clients.startup import StartPyrogram

yinsxd = Var()
xd = PyrogramXd()


try:
    from uvloop import install
except:
    install = None
    logs.info("'uvloop' not installed\ninstall 'uvloop' or add 'uvloop' in requirements.txt")


MSG_ON = """
<b>❏ ᴀʏɪɪɴ - ᴜʙᴏᴛ ʙᴇʀʜᴀsɪʟ ᴅɪᴀᴋᴛɪғᴋᴀɴ</b>
<b>╭╼┅━━━━━╍━━━━━┅╾</b>
<b>├▹ Pʏ-Aʏɪɪɴ Vᴇʀsɪᴏɴ</b> - •[<code>{}</code>]•
<b>├▹ Hᴏsᴛɪɴɢ</b> - <code>{}</code>
<b>├▹ Usᴇʀʙᴏᴛ Vᴇʀsɪᴏɴ</b> - <code>{}</code>
<b>├▹ Tᴏᴛᴀʟ Pʟᴜɢɪɴs</b> - <code>{}</code>
<b>├▹ Tᴏᴛᴀʟ Usᴇʀs</b> - <code>{}</code>
<b>╰╼┅━━━━━╍━━━━━┅╾</b>
"""


async def start_main():
    await StartPyrogram()
    try:
        await tgbot.send_message(
            yinsxd.LOG_CHAT,
            MSG_ON.format(
                __version__,
                HOSTED_ON,
                ayiin_ver, 
                len(CMD_HELP),
                len(Bots),
            )
        )
    except BaseException as s:
        print(s)
    print(f"AyiinUbot Version - {ayiin_ver}\n[🔥 BERHASIL DIAKTIFKAN! 🔥]")
    await idle()
    await aiosession.close()

if __name__ == "__main__":
    install()
    xd.heroku()
    loop.run_until_complete(start_main())
    logs.info(f"{fail_msg}")



from ._core import mongodb

ayiin_conf = mongodb.variable


async def set_var(var, value):
    p_variable = await ayiin_conf.find_one({"_id": var})
    if p_variable:
        await ayiin_conf.update_one({"_id": var}, {"$set": {"ayiin_conf": value}})
    else:
        await ayiin_conf.insert_one({"_id": var, "ayiin_conf": value})


async def get_var(var):
    custom_var = await ayiin_conf.find_one({"_id": var})
    if not custom_var:
        return None
    else:
        g_custom_var = custom_var["ayiin_conf"]
        return g_custom_var


async def del_var(var):
    custom_var = await ayiin_conf.find_one({"_id": var})
    if custom_var:
        await ayiin_conf.delete_one({"_id": var})
        return True
    else:
        return False



#
# Copyright (C) 2021-2022 by TeamYukki@Github, < https://github.com/TeamYukki >.
#
# This file is part of < https://github.com/TeamYukki/YukkiMusicBot > project,
# and is released under the "GNU v3.0 License Agreement".
# Please see < https://github.com/TeamYukki/YukkiMusicBot/blob/master/LICENSE >
#
# All rights reserved.

import aiohttp
import requests

BASE = "https://batbin.me/"

class Paste(object):
    async def post(self, url: str, *args, **kwargs):
        async with aiohttp.ClientSession() as session:
            async with session.post(url, *args, **kwargs) as resp:
                try:
                    data = await resp.json()
                except Exception:
                    data = await resp.text()
            return data


    async def PasteBin(self, text):
        resp = await self.post(f"{BASE}api/v2/paste", data=text)
        if not resp["success"]:
            return
        link = BASE + resp["message"]
        return link


    async def paste(self, content: str):
        resp = await self.post(f"{BASE}api/v2/paste", data=content)
        if not resp["success"]:
            return
        return BASE + resp["message"]


    async def s_paste(self, message, extension="txt"):
        siteurl = "https://spaceb.in/api/v1/documents/"
        try:
            response = requests.post(
                siteurl, data={"content": message, "extension": extension}
            )
        except Exception as e:
            return {"error": str(e)}
        if response.ok:
            response = response.json()
            if response["error"] != "" and response["status"] < 400:
                return {"error": response["error"]}
            return {
                "url": f"https://spaceb.in/{response['payload']['id']}",
                "raw": f"{siteurl}{response['payload']['id']}/raw",
                "bin": "Spacebin",
            }
        return {"error": "Unable to reach spacebin."}



import logging
from datetime import datetime
from traceback import format_exc
import pytz
from fipper import filters
from fipper.errors.exceptions.bad_request_400 import (
    MessageIdInvalid,
    MessageNotModified,
    UserNotParticipant
)
from fipper.types import (
    InlineKeyboardButton,
    InlineKeyboardMarkup,
    InlineQueryResultArticle,
    InputTextMessageContent
)

from fipper.handlers import CallbackQueryHandler, InlineQueryHandler

from .config import Var as Variable
from .decorator import is_admin_or_owner
from .Clients import *


Var = Variable()


MSG_IN = """
**Ayiin - UBot**
➖➖➖➖➖➖➖➖➖➖
**Owner**: [{}](tg://user?id={})
**Support**: @AyiinChat

**Buat Ubot Anda Sendiri Di** @AyiinChat
➖➖➖➖➖➖➖➖➖➖
"""    


IN_BTTS = [
    [
        InlineKeyboardButton(
            "Repository",
            url="https://github.com/AyiinXd/AyiinUbot",
        ),
        InlineKeyboardButton(
            "Support", 
            url="https://t.me/AyiinChat"),
    ]
]



def inline(
    pattern: str = None,
    group: int = 0,
    client_only: bool = False,
):
    """- Main Decorator To Register Commands. -"""
    filterm = (
        filters.regex(pattern=pattern)
    )

    def yinsxd(func):
        async def wrapper(tgbot, iq):
            me = await AYIIN1.get_me()
            OWNER = me.first_name + " " + me.last_name if me.last_name else ""
            OWNER_ID = me.id
            if client_only and iq.from_user.id not in client_id:
                results=[
                    (
                        InlineQueryResultArticle(
                            title="Ayiin Ubot!",
                            reply_markup=InlineKeyboardMarkup(IN_BTTS),
                            input_message_content=InputTextMessageContent(MSG_IN.format(OWNER, OWNER_ID)),
                        )
                    )
                ],
                await iq.answer(
                    results,
                    switch_pm_text=f"🤖: Assistant of {OWNER}",
                    switch_pm_parameter="start",
                )
                return
            try:
                await func(tgbot, iq)
            except BaseException:
                logging.error(
                    f"Exception - {func.__module__} - {func.__name__}"
                )
                TZZ = pytz.timezone(Var.TZ)
                datetime_tz = datetime.now(TZZ)
                text = "<b>!ERROR - REPORT!</b>\n\n"
                text += f"\n<b>Dari:</b> <code>{OWNER}</code>"
                text += f"\n<b>Trace Back : </b> <code>{str(format_exc())}</code>"
                text += f"\n<b>Plugin-Name :</b> <code>{func.__module__}</code>"
                text += f"\n<b>Function Name :</b> <code>{func.__name__}</code> \n"
                text += datetime_tz.strftime(
                    "<b>Date :</b> <code>%Y-%m-%d</code> \n<b>Time :</b> <code>%H:%M:%S</code>"
                )
                try:
                    xx = await tgbot.send_message(Var.LOG_CHAT, text)
                    await xx.pin(disable_notification=False)
                except BaseException:
                    logging.error(text)
        add_handler(filterm, wrapper, pattern, group)
        return wrapper

    return yinsxd


def add_handler(filter_s, func_, pattern, group):
    if tgbot:
        tgbot.add_handler(InlineQueryHandler(func_, filters=filter_s), group=group)


def callback(
    pattern: str = None,
    group: int = 0,
    from_users: list = [],
    client_only: bool = False,
    users: bool = False,
    admins: bool = False,
):
    """- Main Decorator To Register Commands. -"""
    filterm = (
        filters.regex(pattern=pattern)
    )

    def yinsxd(func):
        async def wrapper(tgbot, cq):
            me = await AYIIN1.get_me()
            OWNER = me.first_name + " " + me.last_name if me.last_name else ""
            OWNER_ID = me.id
            if "me" in from_users:
                from_users.remove("me")
                for bot in Bots:
                    mebot = await bot.get_me()
                    from_users.append(mebot.id)
            if client_only and cq.from_user.id not in client_id:
                return await cq.answer(
                    "Ini Bukan Userbot Anda, Silahkan Buat Userbot Anda Di @AyiinChat",
                    show_alert=True,
                )
            if admins and not await is_admin_or_owner(
                cq.message, from_users
            ):
                return await cq.answer(
                    "Lu Bukan Admin Di Gc Ini Tod...",
                    show_alert=True,
                )
            try:
                await func(tgbot, cq)
            except MessageNotModified:
                    pass
            except MessageIdInvalid:
                logging.warning(
                    "Please Don't Delete Commands While it's Processing..."
                )
            except UserNotParticipant:
                pass
            except BaseException:
                logging.error(
                    f"Exception - {func.__module__} - {func.__name__}"
                )
                TZZ = pytz.timezone(Var.TZ)
                datetime_tz = datetime.now(TZZ)
                text = "<b>!ERROR - REPORT!</b>\n\n"
                text += f"\n<b>Dari:</b> <code>{OWNER}</code>"
                text += f"\n<b>Trace Back : </b> <code>{str(format_exc())}</code>"
                text += f"\n<b>Plugin-Name :</b> <code>{func.__module__}</code>"
                text += f"\n<b>Function Name :</b> <code>{func.__name__}</code> \n"
                text += datetime_tz.strftime(
                    "<b>Date :</b> <code>%Y-%m-%d</code> \n<b>Time :</b> <code>%H:%M:%S</code>"
                )
                try:
                    xx = await tgbot.send_message(Var.LOG_CHAT, text)
                    await xx.pin(disable_notification=False)
                except BaseException:
                    logging.error(text)
        add2_handler(filterm, wrapper, pattern, group)
        return wrapper

    return yinsxd


def add2_handler(filter_s, func_, pattern, group):
    if tgbot:
        tgbot.add_handler(CallbackQueryHandler(func_, filters=filter_s), group=group)
